/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import { Rule } from "../../components/rule";
import { Social } from "../../components/social";
import { Donate, HireMe, Socials } from "../../config/Socials";
import type { JSX } from "react";

/**
 * Renders the /contact page.
 * @returns A React Component.
 */
const Contact = (): JSX.Element => {
  return (
    <main className="w-4/5 text-center max-w-4xl m-auto mt-16 mb-16 rounded-lg">
      <h1 className="text-5xl">{`Contact Us`}</h1>
      <p>
        {`We offer many different ways to get in touch with us. This page lists
        all of our available social media accounts. Use the buttons below to
        choose your preferred method.`}
      </p>
      <p>
        {`Note that the items are sorted alphabetically, not by order of
        response times. Monitoring levels and activity may vary by platform.`}
      </p>
      <p>
        {`With ${Socials.length.toLocaleString("en-GB")} choices, you shouldn't have any complaints!
        :3`}
      </p>
      <Rule />
      <section>
        <div>
          {[ HireMe, Donate ].map(
            ({ link, label, alt, icon, color, background }) => {
              return <Social
                alt={alt}
                background={background}
                color={color}
                icon={icon}
                key={label}
                label={label}
                link={link}
              />;
            }
            ,
          )}
          {Socials.toSorted((a, b) => {
            return a.label.localeCompare(b.label);
          }).map(
            ({ link, label, alt, icon, color, background }) => {
              return <Social
                alt={alt}
                background={background}
                color={color}
                icon={icon}
                key={label}
                label={label}
                link={link}
              />;
            }
            ,
          )}
        </div>
      </section>
    </main>
  );
};

export default Contact;
