/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import Image from "next/image";
import React, { type JSX } from "react";
import { NavItems } from "../config/NavItems";

/**
 * Renders the main React component.
 * @returns A JSX element.
 */
const Home = (): JSX.Element => {
  return (
    <div>
      <div
        className="absolute top-0 right-[33vw] z-100
        w-[100vh] h-[100vh] rotate-90 hidden lg:block"
      >
        <svg className="absolute" viewBox="0 0 500 500">
          <path
            d="M0,100 C150,200 350,0 500,100 L500,00 L0,0 Z"
            style={{ fill: "var(--foreground)", stroke: "none" }}
          ></path>
        </svg>
      </div>
      <main className="grid grid-cols-[2fr,1fr] min-h-screen">
        <section
          className="bg-[--background] text-[--foreground]
          flex flex-col items-left justify-center text-left pl-5"
        >
          <h1 className="text-4xl mb-2">{`Naomi Carrigan`}</h1>
          <Image
            alt="Naomi Carrigan"
            className="rounded-full"
            height={200}
            src="https://cdn.nhcarrigan.com/profile.png"
            width={200}
          />
          <p className="text-3xl">{`Software Engineer`}</p>
          <p className="text-3xl">{`Community Manager`}</p>
        </section>
        <section
          className="bg-[--foreground] text-[--background]
          flex flex-col items-center justify-center"
        >
          {NavItems.map((item, index) => {
            return (
              <a
                className="block py-2 px-4 text-2xl
              hover:bg-[--background] hover:text-[--foreground]"
                href={item.href}
                key={item.href}
              >
                {index % 2 === 1
                  ? "🩷"
                  : "🩵"} {item.text}
              </a>
            );
          })}
        </section>
      </main>
    </div>
  );
};

export default Home;
